LockManager class

─── LockManager (V1) ──────────────────────────────────────────────────────

Provides per-table read/write locks. Thread-safe within a single Dart isolate (cooperative multitasking via async/await).

Constructors

LockManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquireAll(List<String> tables, LockMode mode) Future<List<LockGrant>>
Acquire locks on multiple tables in canonical (sorted) order to prevent deadlock via circular-wait prevention.
acquireRead(String table) Future<LockGrant>
acquireWrite(String table) Future<LockGrant>
isWriteLocked(String table) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readerCount(String table) int
release(LockGrant grant) → void
releaseAll(List<LockGrant> grants) → void
toString() String
A string representation of this object.
inherited
withRead<T>(String table, Future<T> fn()) Future<T>
withWrite<T>(String table, Future<T> fn()) Future<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited