LockManagerV2 class

Constructors

LockManagerV2()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquireAll(List<String> tables, LockMode mode, {int timeoutMs = 5000}) Future<List<LockGrant>>
acquireRead(String table, {int timeoutMs = 5000}) Future<LockGrant>
Acquire a shared (read) lock on table.
acquireWrite(String table, {int timeoutMs = 5000}) Future<LockGrant>
Acquire an exclusive (write) lock on table.
hasWriter(String table) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readerCount(String table) int
release(LockGrant grant) → void
Release a lock (read or write).
releaseAll(List<LockGrant> grants) → void
Release all grants in a list.
status() Map<String, Map<String, dynamic>>
toString() String
A string representation of this object.
inherited
withRead<T>(String table, Future<T> fn(), {int timeoutMs = 5000}) Future<T>
withWrite<T>(String table, Future<T> fn(), {int timeoutMs = 5000}) Future<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited