Database class
Properties
-
btreeIndexes
→ Map<
String, Map< String, BTreeV2> > -
final
- cache ↔ PageCache
-
getter/setter pair
- committedTxns → CommittedTxnsFilter
-
no setter
- dir → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockManager → LockManagerV2
-
no setter
-
mvccTables
→ Map<
String, MvccTable> -
final
- pager ↔ Pager
-
getter/setter pair
-
pageTables
→ Map<
String, PageTable> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statsRegistry → StatsRegistry
-
final
-
tables
→ Map<
String, Table> -
final
- txnManager ↔ TransactionManagerV2
-
getter/setter pair
- vfs → VfsAdapter
-
final
- wal ↔ Wal
-
getter/setter pair
Methods
-
abortTxn(
TxnContextV2 ctx) → void -
analyze(
String tableName) → Future< void> -
analyzeAll(
) → Future< void> -
autoCommitDone(
TxnContextV2 ctx) → void -
autoCommitRead(
) → TxnContextV2 -
beginTxn(
{bool readOnly = false}) → TxnContextV2 -
btreeDelete(
String table, String column, dynamic key, int rowId) → void -
btreeInsert(
String table, String column, dynamic key, int rowId) → void -
btreeLookup(
String table, String column, dynamic key) → List< int> -
checkpoint(
) → Future< void> -
close(
) → Future< void> -
commitTxn(
TxnContextV2 ctx) → void -
createTable(
String name, Schema schema) → Future< Table> -
dropTable(
String name) → Future< void> -
getTable(
String name) → Table? -
mvccTableFor(
String name) → MvccTable -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rollback(
) → Future< void> -
saveSnapshot(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
vacuum(
) → Future< void> -
walAppend(
WalOp op, String table, Map< String, dynamic> payload, {int? txnId}) → Future<int>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
String dirPath, {VfsAdapter? vfsAdapter}) → Future< Database>