setLsn method
Set the WAL LSN that will be stamped into pages written during the current operation. Called by Executor after wal.append().
Implementation
void setLsn(int lsn) => _currentLsn = lsn;
Set the WAL LSN that will be stamped into pages written during the current operation. Called by Executor after wal.append().
void setLsn(int lsn) => _currentLsn = lsn;