BTree class

Constructors

BTree({int order = 4, required String path, VfsAdapter? vfs})

Properties

hashCode int
The hash code for this object.
no setterinherited
order int
final
path String
final
root BTreeNode
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
delete(dynamic key, int rowId) → void
insert(dynamic key, int rowId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rangeSearch(dynamic low, dynamic high) List<int>
save({VfsAdapter? vfs}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(String path, {int order = 4, VfsAdapter? vfs}) Future<BTree>