BTreeKey class

Implemented types

Constructors

BTreeKey(dynamic value)

Properties

hashCode int
The hash code for this object.
no setteroverride
keyType int
no setter
raw → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(BTreeKey other) int
Compares this object to another object.
override
encode() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(BTreeKey other) bool
operator <=(BTreeKey other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(BTreeKey other) bool
operator >=(BTreeKey other) bool

Static Methods

decode(Uint8List data, int offset) → (BTreeKey, int)