compareTo method

  1. @override
int compareTo(
  1. BTreeKey other
)
override

Compares this object to another object.

Returns a value like a Comparator when comparing this to other. That is, it returns a negative integer if this is ordered before other, a positive integer if this is ordered after other, and zero if this and other are ordered together.

The other argument must be a value that is comparable to this object.

Implementation

@override
int compareTo(BTreeKey other) {
  final a = _value;
  final b = other._value;
  if (a is num && b is num) return a.compareTo(b);
  return a.toString().compareTo(b.toString());
}