CommittedTxnsFilter class

Constructors

CommittedTxnsFilter()

Properties

all Set<int>
no setter
count int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evict(int oldestActiveTxnId) → void
isCommitted(int txnId) bool
markCommitted(int txnId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String dirPath, VfsAdapter vfs) Future<void>
seed(Iterable<int> txnIds) → void
toBytes() Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited