TxnState class

Constructors

TxnState({required int nextTxnId, required int lastCommitted, required int checkpointLsn})
TxnState.fresh()
factory

Properties

checkpointLsn int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastCommitted int
getter/setter pair
nextTxnId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(Uint8List bytes) TxnState?