CboJoinPlan class
Constructors
- CboJoinPlan(MultiJoinPlan joinPlan, SelectStmt stmt, CostEstimate est)
Properties
- actualRows ↔ int?
-
getter/setter pairinherited
- actualTimeMs ↔ double?
-
getter/setter pairinherited
- estimate → CostEstimate
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinPlan → MultiJoinPlan
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stmt → SelectStmt
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited