CboPlanner class
Constructors
-
CboPlanner({required Map<
String, TableMeta> catalog, required StatsRegistry stats})
Properties
-
catalog
→ Map<
String, TableMeta> -
final
- costModel → CostModel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinPlanner → MultiJoinPlanner
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stats → StatsRegistry
-
final
Methods
-
explainPlan(
Plan plan) → List< Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
planSelect(
SelectStmt stmt) → Plan -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited