CostModel class

The cost model: given statistics, estimate plan costs.

Constructors

CostModel(StatsRegistry stats)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats StatsRegistry
final

Methods

cheapest(CostEstimate a, CostEstimate b) CostEstimate
hashJoin({required CostEstimate outerPlan, required CostEstimate innerPlan, required double joinSelectivity}) CostEstimate
indexEqualityScan(String table, String column, dynamic value) CostEstimate
indexRangeScan(String table, String column, dynamic low, dynamic high) CostEstimate
nestedLoopJoin({required CostEstimate outerPlan, required CostEstimate innerPlan, required double joinSelectivity, bool innerHasIndex = false}) CostEstimate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seqScan(String table) CostEstimate
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited