JoinGraph class

The join graph: tables as nodes, join predicates as edges.

Constructors

JoinGraph({required List<String> tables, required List<JoinEdge> edges})

Properties

edges List<JoinEdge>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<String>
final

Methods

edgeBetween(String a, String b) JoinEdge?
Return the edge connecting a and b, or null.
neighbors(String table) List<String>
Return all tables directly connected to table via an edge.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited