MultiJoinPlan class
A complete multi-table join plan.
Constructors
-
MultiJoinPlan(List<
PhysicalJoinOp> ops)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ops
→ List<
PhysicalJoinOp> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCost → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited