StatisticsCollector class

Collects statistics from a table's rows.

Constructors

StatisticsCollector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

collect(String tableName, List<Map<String, dynamic>> rows) TableStats
Build TableStats from a list of row maps.