TableStats class

Statistics for a full table.

Constructors

TableStats({required String tableName, required int rowCount, required int pageCount, required Map<String, ColumnStats> columns, DateTime? collectedAt})

Properties

collectedAt DateTime
final
columns Map<String, ColumnStats>
final
columnStats Map<String, ColumnStats>
Alias for columns — used by persistence layer.
no setter
hashCode int
The hash code for this object.
no setterinherited
pageCount int
final
rowCount int
final
rowsPerPage double
Average rows per page (for I/O cost estimation).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final

Methods

column(String name) ColumnStats?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited