CostConfig class

Constructors

CostConfig({double seqIoCost = 1.0, double randomIoCost = 1.25, double cpuTupleCost = 0.01, double cpuOperatorCost = 0.0025, double indexFetchCost = 0.5, double rowsPerPage = 60.0})
const

Properties

cpuOperatorCost double
final
cpuTupleCost double
final
hashCode int
The hash code for this object.
no setterinherited
indexFetchCost double
final
randomIoCost double
final
rowsPerPage double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seqIoCost double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

hdd → const CostConfig
memory → const CostConfig
nvme → const CostConfig