QueryResult class

Constructors

QueryResult({List<Map<String, dynamic>> rows = const [], int affectedRows = 0, String? message})
const

Properties

affectedRows int
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
rows List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint() → void
Pretty-print as ASCII table (for REPL / testing).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited