Lexer class

Constructors

Lexer(String input)

Properties

hashCode int
The hash code for this object.
no setterinherited
input String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tokenize() List<Token>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

keywords → const Set<String>