AggExpr class

An aggregate expression e.g. COUNT(*), SUM(price), AVG(score)

Inheritance

Constructors

AggExpr({required AggFunc func, Expr? arg, bool distinct = false, String? alias})

Properties

alias String?
final
arg Expr?
final
distinct bool
final
func AggFunc
final
hashCode int
The hash code for this object.
no setterinherited
label String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited