CreateTableStmt class

Inheritance

Constructors

CreateTableStmt({required String table, required Schema schema, bool ifNotExists = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
ifNotExists bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema Schema
final
table String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited