FuncCallExpr class

Scalar function call: LOWER(x), UPPER(x), TRIM(x), LENGTH(x), COALESCE(a,b,...), SUBSTR(s,start,len), CAST(x AS type)

Inheritance

Constructors

FuncCallExpr(String func, List<Expr> args)

Properties

args List<Expr>
final
func String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited