OrderByClause class

Constructors

OrderByClause(Expr expr, {bool ascending = true, bool nullsFirst = false})

Properties

ascending bool
final
expr Expr
final
hashCode int
The hash code for this object.
no setterinherited
nullsFirst bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited