SelectColumn class
A selected column (regular expr OR aggregate)
Constructors
- SelectColumn(Expr expr, {String? alias})
Properties
- alias → String?
-
final
- effectiveAlias → String
-
no setter
- expr → Expr
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited