SelectStmt class

Inheritance

Constructors

SelectStmt({bool distinct = false, required List<SelectColumn> columns, required String table, JoinSpec? join, List<JoinSpec>? joins, Expr? where, List<Expr> groupBy = const [], Expr? having, List<OrderByClause> orderBy = const [], int? limit, int? offset})

Properties

allTables List<String>
All tables referenced (primary + joined).
no setter
columns List<SelectColumn>
final
distinct bool
final
groupBy List<Expr>
final
hasAggregates bool
True when the query has at least one aggregate function in the column list.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasJoins bool
True when the query has any joins.
no setter
having Expr?
final
isScalarAggregate bool
True when this query returns only aggregate results (no GROUP BY needed).
no setter
join JoinSpec?
final
joins List<JoinSpec>
All joins in order (may be empty, one, or many).
final
limit int?
final
offset int?
final
orderBy List<OrderByClause>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
where Expr?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited