hasAggregates property
bool
get
hasAggregates
True when the query has at least one aggregate function in the column list.
Implementation
bool get hasAggregates => columns.any((c) => c.expr is AggExpr);
True when the query has at least one aggregate function in the column list.
bool get hasAggregates => columns.any((c) => c.expr is AggExpr);