IndexLookupPlan class

Exact-match index lookup

Inheritance

Constructors

IndexLookupPlan(String table, String column, dynamic value, Expr? extraFilter)

Properties

column String
final
extraFilter Expr?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited