JoinPlan class

Hash JOIN between two plans

Inheritance

Constructors

JoinPlan(Plan left, Plan right, SelectStmt stmt)

Properties

hashCode int
The hash code for this object.
no setterinherited
left Plan
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stmt SelectStmt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited