Planner class

Constructors

Planner(Map<String, TableMeta> catalog)

Properties

catalog Map<String, TableMeta>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
planSelect(SelectStmt stmt) Plan
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited