RangeScanPlan class

B-Tree range scan

Inheritance

Constructors

RangeScanPlan(String table, String column, dynamic low, dynamic high, Expr? extraFilter)

Properties

column String
final
extraFilter Expr?
final
hashCode int
The hash code for this object.
no setterinherited
high → dynamic
final
low → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited