PageCache class

Available extensions

Constructors

PageCache(Pager pager, {int capacity = 256})

Properties

capacity int
final
dirtyPageCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
pager Pager
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setter

Methods

flushAll() Future<void>
flushPage(int pageId) Future<void>

Available on PageCache, provided by the PageCacheCheckpoint extension

Flush a single page to the pager (if dirty). Used by CheckpointManager for incremental dirty-page flushing.
get(int pageId) Future<Uint8List>
invalidate() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(int pageId, Uint8List data) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited