CheckpointResult class

Constructors

CheckpointResult({required int dirtyPagesFlushed, required int walRecordsTruncated, required int tablesCheckpointed, required int indexesWritten, required Duration elapsed, required int checkpointLsn})
const

Properties

checkpointLsn int
final
dirtyPagesFlushed int
final
elapsed Duration
final
hashCode int
The hash code for this object.
no setterinherited
indexesWritten int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablesCheckpointed int
final
walRecordsTruncated int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited