PageHeader class

Constructors

PageHeader({required int pageId, required int lsn, required int dataLength, required int nextPageId, required int checksum})
const

Properties

checksum int
final
dataLength int
final
hashCode int
The hash code for this object.
no setterinherited
lsn int
final
nextPageId int
final
pageId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(Uint8List page) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeChecksum(Uint8List page, int len) int
read(Uint8List page) PageHeader?

Constants

magic → const int
noNextPage → const int
size → const int