DirtyPageTracker class

Constructors

DirtyPageTracker()

Properties

dirtyCount int
no setter
dirtyPages Set<int>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
isDirty(int pageId) bool
markClean(int pageId) → void
markDirty(int pageId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited