PageTable class

Constructors

PageTable({required TableMeta meta, required PageCache cache, required String indexDir})

Properties

cache PageCache
final
dirtyPageIds Set<int>
no setter
dirtyTracker DirtyPageTracker
final
hashCode int
The hash code for this object.
no setterinherited
indexDir String
final
meta TableMeta
final
name String
no setter
nextRowId int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema Schema
no setter

Methods

clearUnsafe() Future<void>
findLocation(int rowId) Future<TupleLocation?>
insert({required Map<String, dynamic> values, required int xmin, int rowId = 0}) Future<TupleLocation>
markCheckpointDone() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recalcNextRowId() Future<void>
scan({required bool isVisible(int xmin, int xmax)}) Future<List<DecodedTuple>>
scanAll() Future<List<DecodedTuple>>
setLsn(int lsn) → void
stampXmax(TupleLocation loc, int txnId) Future<void>
toString() String
A string representation of this object.
inherited
vacuum({required int oldestActiveTxnId}) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited