PageConst class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- headerSize → const int
- magic → const int
- mvccFlags → const int
- mvccHeaderSize → const int
- mvccRowId → const int
- mvccXmax → const int
- mvccXmin → const int
- noNextPage → const int
- pageSize → const int
- slotAlive → const int
- slotOverflow → const int
- slotSize → const int
- typeData → const int
- typeFreelist → const int
- typeIndexInternal → const int
- typeIndexLeaf → const int
- typeOverflow → const int