PageValidation class

Constructors

PageValidation(PageValStatus status)
const

Properties

checksumFail bool
no setter
hashCode int
The hash code for this object.
no setterinherited
ok bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PageValStatus
final
uninitialized bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited