MvccTupleHeader class
Constructors
- MvccTupleHeader({required int xmin, required int xmax, required int rowId, int mvccFlags = 0})
-
const
Properties
Methods
-
encode(
ByteData bd, {int offset = 0}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
withXmax(
int txnId) → MvccTupleHeader
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Uint8List data, {int offset = 0}) → MvccTupleHeader