TupleCodec class

Constructors

TupleCodec()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Schema schema, Uint8List data) DecodedTuple
encode({required Schema schema, required Map<String, dynamic> values, required MvccTupleHeader header}) Uint8List
peekRowId(Uint8List data) int
peekXmax(Uint8List data) int
peekXmin(Uint8List data) int