VfsFile class abstract
- Implementers
Constructors
- VfsFile()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Close this file handle.
-
flush(
) → Future< void> - Flush (fsync) to durable storage. No-op on in-memory backend.
-
length(
) → Future< int> - Current byte length of the file.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readBytes(
int offset, int count) → Future< Uint8List> -
Read
countbytes starting atoffset. Returns fewer bytes if EOF. -
toString(
) → String -
A string representation of this object.
inherited
-
writeBytes(
int offset, Uint8List data) → Future< void> -
Write
dataatoffset. Extends the file if necessary.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited