MemVfsAdapter class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
isWeb bool
True if this is the in-memory (web) backend.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendBytes(String path, Uint8List data) Future<void>
Append data to path (creates if absent).
override
delete(String path) Future<void>
Delete path. No-op if absent.
override
ensureDir(String dir) Future<void>
Create dir and all parents if they don't exist.
override
exists(String path) Future<bool>
True if path exists.
override
listNames(String dir) Future<List<String>>
Return base-names of all entries in dir.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openRaf(String path) Future<VfsFile>
Open (or create) a random-access file at path.
override
readAll(String path) Future<Uint8List>
Read entire file as bytes. Returns empty list if not found.
override
rename(String src, String dst) Future<void>
Rename src to dst atomically.
override
toString() String
A string representation of this object.
inherited
writeAll(String path, Uint8List data) Future<void>
Write data to path atomically (write-then-rename on IO).
override

Operators

operator ==(Object other) bool
The equality operator.
inherited