Wal class
Properties
- currentLsn → int
-
no setter
- currentTxnId → int
-
no setter
- flushedLsn → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
append(
WalOp op, String table, Map< String, dynamic> payload, {int? txnId}) → Future<int> -
appendBatch(
List< ({WalOp op, Map< ops) → Future<String, dynamic> payload, String table, int? txnId})>int> -
beginTransaction(
int txnId) → Future< void> -
close(
) → Future< void> -
committedRecords(
) → Future< List< WalRecord> > -
commitTransaction(
int txnId) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAll(
) → Future< List< WalRecord> > -
rollbackTransaction(
int txnId) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
truncate(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
String path, {required VfsAdapter vfs}) → Future< Wal>