WalBinOp enum
Values
- insert → const WalBinOp
-
const WalBinOp(0x01) - update → const WalBinOp
-
const WalBinOp(0x02) - delete → const WalBinOp
-
const WalBinOp(0x03) - begin → const WalBinOp
-
const WalBinOp(0x10) - commit → const WalBinOp
-
const WalBinOp(0x11) - rollback → const WalBinOp
-
const WalBinOp(0x12) - createTable → const WalBinOp
-
const WalBinOp(0x20) - dropTable → const WalBinOp
-
const WalBinOp(0x21) - checkpoint → const WalBinOp
-
const WalBinOp(0x30)
Properties
- code → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isDataOp → bool
-
no setter
- isTxnOp → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited