WalBinary class

Properties

currentLsn int
no setter
currentTxnId int
no setter
flushedLsn int
no setter
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyzeForRecovery() Future<({int lastCheckpointLsn, List<WalBinRecord> toRedo, Set<int> uncommittedTxns})>
append(WalBinRecord builder(int lsn, int prevLsn)) Future<int>
appendBatch(List<WalBinRecord Function(int lsn, int prevLsn)> builders) Future<int>
appendCreateTable(String tableName, Map<String, dynamic> schemaJson) Future<int>
appendDelete({required int txnId, required int tableId, required int rowId, required Uint8List beforeImage, required int xmaxStamp}) Future<int>
appendDropTable(String tableName) Future<int>
appendInsert({required int txnId, required int tableId, required int rowId, required Uint8List afterImage}) Future<int>
appendUpdate({required int txnId, required int tableId, required int rowId, required Uint8List beforeImage, required Uint8List afterImage}) Future<int>
beginTransaction(int txnId, int tableId) Future<int>
close() Future<void>
commitTransaction(int txnId, int tableId) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAll({int afterLsn = 0}) Future<List<WalBinRecord>>
rollbackTransaction(int txnId, int tableId) Future<int>
toString() String
A string representation of this object.
inherited
truncate() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

open(String path, {required VfsAdapter vfs}) Future<WalBinary>