Schema class

Constructors

Schema(List<Column> columns)
Schema.fromJson(Map<String, dynamic> json)
factory

Properties

columns List<Column>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findColumn(String name) Column?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primaryKey() Column?
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
validate(Map<String, dynamic> row) → void
التحقق من أن الصف يطابق المخطط

Operators

operator ==(Object other) bool
The equality operator.
inherited