TransactionManager class
Manages all active transactions and provides MVCC snapshot information.
Constructors
Properties
- activeCount → int
-
no setter
-
activeIds
→ Set<
int> -
Set of currently active txnIds (for write-write conflict detection).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastCommittedTxnId → int
-
no setter
- lockManager → LockManager
-
final
- oldestActiveTxnId → int
-
Returns the lowest active txnId (used for vacuum: all versions older
than this are invisible to all current and future transactions).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
abort(
TxnContext ctx) → void - Mark a transaction aborted, release its locks.
-
autoCommitRead(
) → TxnContext - A read-only autocommit context (no BEGIN/COMMIT overhead).
-
begin(
) → TxnContext - Start a new transaction. Returns its TxnContext.
-
commit(
TxnContext ctx) → void - Mark a transaction committed, release its locks.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited