TransactionManagerV2 class

Constructors

TransactionManagerV2({required LockManagerV2 lockManager, required String dataDir})

Properties

activeCount int
no setter
activeIds Set<int>
no setter
committed CommittedTxnsFilter
final
hashCode int
The hash code for this object.
no setterinherited
lastCommittedTxnId int
no setter
lockManager LockManagerV2
final
nextTxnId int
no setter
oldestActiveTxnId int
The oldest active txnId (for vacuum threshold). If no transactions are active, returns _nextTxnId (all committed rows with xmax < _nextTxnId are safe to vacuum).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

abort(TxnContextV2 ctx) → void
autoCommitDone(TxnContextV2 ctx) → void
Must be called after autoCommitRead() finishes the read.
autoCommitRead() TxnContextV2
begin({bool readOnly = false}) TxnContextV2
commit(TxnContextV2 ctx) → void
getContext(int txnId) TxnContextV2?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persistStateAt(int checkpointLsn) Future<void>
restoreFromPersistence({int walMaxTxnId = 0}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited