Table class
Constructors
Properties
Methods
-
clear(
) → Future< void> - Clear all rows (used by ROLLBACK).
-
delete(
bool where(Row)) → Future< int> -
Delete rows matching
where. Returns affected count. -
findByIndex(
String column, dynamic value) → Future< List< Row> > - Index lookup.
-
insert(
Row row) → Future< void> - Insert a new row. Assigns id if row.id <= 0.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
persistIndexes(
{VfsAdapter? vfs}) → Future< void> -
recalcNextRowId(
) → Future< void> -
scan(
) → Future< List< Row> > - Full table scan — returns all rows.
-
setLsn(
int lsn) → void - Set the WAL LSN that will be stamped into pages written during the current operation. Called by Executor after wal.append().
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
bool where(Row), Map< String, dynamic> updates) → Future<int> -
Update rows matching
where. Returns affected count.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited