MvccVisibility class
Constructors
-
MvccVisibility({required int currentTxnId, required int snapshotTxnId, required Set<
int> activeAtBegin, required CommittedTxnsFilter committed}) -
const
- MvccVisibility.forAutoCommit({required int txnId, required int lastCommitted, required CommittedTxnsFilter committed})
-
factory
Properties
-
activeAtBegin
→ Set<
int> -
final
- committed → CommittedTxnsFilter
-
final
- currentTxnId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotTxnId → int
-
final
Methods
-
isVisible(
int xmin, int xmax) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited