VacuumStrategy class

Constructors

VacuumStrategy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

safeVacuumXmax({required int oldestActiveTxnId, required CommittedTxnsFilter committed}) int
Compute the safe xmax threshold for vacuum.
shouldVacuum({required int liveRows, required int estimatedDeadRows}) bool
Returns true if autovacuum should be triggered for a table.