MvccRowVersion class

A single row version in the MVCC chain.

Constructors

MvccRowVersion({required int rowId, required Map<String, dynamic> values, required int createdByTxn, int? deletedByTxn, MvccRowVersion? prev})

Properties

createdByTxn int
final
deletedByTxn int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
prev MvccRowVersion?
Link to previous (older) version; null for oldest.
getter/setter pair
rowId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, dynamic>
final

Methods

clone() MvccRowVersion
Deep clone for safe mutation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialise to JSON for WAL / persistence.
toString() String
A string representation of this object.
override
visibleTo(TxnContext ctx) bool
Determine if this version is visible to ctx.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> j) MvccRowVersion
Deserialise from JSON (recovery / WAL replay).