MvccVersionChain class

Head of the version chain for one logical row. The head is always the most-recent version.

Constructors

MvccVersionChain(MvccRowVersion head)

Properties

hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
vacuum(int threshold) → void
Prune versions that can no longer be seen by any active transaction. threshold = oldestActiveTxnId from TransactionManager.
visibleVersion(TxnContext ctx) MvccRowVersion?
Find the version visible to ctx, walking the chain.

Operators

operator ==(Object other) bool
The equality operator.
inherited