CboIndexScanPlan class
Constructors
- CboIndexScanPlan(String table, String column, dynamic value, Expr? extraFilter, CostEstimate est)
Properties
- actualRows ↔ int?
-
getter/setter pairinherited
- actualTimeMs ↔ double?
-
getter/setter pairinherited
- column → String
-
final
- estimate → CostEstimate
-
finalinherited
- extraFilter → Expr?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → String
-
final
- value → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited