MultiJoinPlanner class
Constructors
- MultiJoinPlanner({required StatsRegistry statsRegistry, required CostModel costModel, required bool hasIndex(String table, String column)})
Properties
- costModel → CostModel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIndex → bool Function(String table, String column)
-
Whether an equi-join index exists on a given column.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statsRegistry → StatsRegistry
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plan(
JoinGraph graph) → MultiJoinPlan -
Produce the best join plan for
graph. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited