PhysicalJoinOp class
A physical join operation (one step in the join pipeline).
Constructors
- PhysicalJoinOp({required String leftTable, required String rightTable, required JoinEdge edge, required PhysicalJoinType method, required CostEstimate cost})
Properties
- cost → CostEstimate
-
final
- edge → JoinEdge
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftTable → String
-
final
- method → PhysicalJoinType
-
final
- rightTable → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited