ColumnStats class
Statistics for a single column.
Constructors
- ColumnStats({required String columnName, required int ndv, dynamic minValue, dynamic maxValue, double nullFraction = 0.0})
-
const
Properties
- columnName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxValue → dynamic
-
final
- minValue → dynamic
-
final
- ndv → int
-
final
- nullFraction → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
equalitySelectivity(
) → double - Selectivity of equality predicate col = value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rangeSelectivity(
dynamic low, dynamic high) → double - Selectivity of range predicate low ≤ col ≤ high.
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited