StatsRegistry class

Global statistics registry — one TableStats per table.

Available extensions

Constructors

StatsRegistry()

Properties

allStats Map<String, TableStats>
Expose all stats for persistence.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

estimateCardinality({required String table, required String? column, required String op, dynamic value, dynamic low, dynamic high}) double
Estimate output cardinality after applying a predicate.
get(String table) TableStats?
has(String table) bool
isStale(String table, {Duration maxAge = const Duration(hours: 24)}) bool
Returns true if stats for table are stale (older than maxAge).
isStaleFor(String tableName, {Duration maxAge = const Duration(hours: 24)}) bool

Available on StatsRegistry, provided by the StatsRegistryPersistenceExt extension

Returns true if stats for tableName are stale (collected more than maxAge ago).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String table) → void
Remove stats for a table (used when table is dropped).
toString() String
A string representation of this object.
inherited
update(TableStats stats) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited