RangeScanPlan class
B-Tree range scan
Constructors
- RangeScanPlan(String table, String column, dynamic low, dynamic high, Expr? extraFilter)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited