CheckpointManager class
Constructors
-
CheckpointManager({required PageCache cache, required Pager pager, required Wal wal, required String dataDir, required Map<
String, PageTable> getTables(), required Future<void> persistTxnState(int pageId), required Future<void> persistStats(), required Future<void> persistCatalog(), required Future<void> persistIndexes(Map<String, PageTable> ), int autocheckpointThreshold = 1000})
Properties
- autocheckpointThreshold ↔ int
-
getter/setter pair
- cache → PageCache
-
final
- dataDir → String
-
final
-
getTables
→ Map<
String, PageTable> Function() -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastCheckpointLsn ↔ int
-
getter/setter pair
- pager → Pager
-
final
-
persistCatalog
→ Future<
void> Function() -
final
-
persistIndexes
→ Future<
void> Function(Map<String, PageTable> ) -
final
-
persistStats
→ Future<
void> Function() -
final
-
persistTxnState
→ Future<
void> Function(int pageId) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wal → Wal
-
final
Methods
-
maybeAutoCheckpoint(
int currentWalRecordCount) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runCheckpoint(
) → Future< CheckpointResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited