Pager class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPages → int
-
no setter
- walFlushedLsn → int
-
no setter
Methods
-
allocatePage(
) → Future< int> -
close(
) → Future< void> -
flush(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rawWritePage(
int pageId, Uint8List page) → Future< void> -
readPage(
int pageId) → Future< Uint8List> -
setWalFlushedLsn(
int lsn) → void -
toString(
) → String -
A string representation of this object.
inherited
-
validatePage(
Uint8List page, int expectedPageId) → PageValidationResult
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- maxPayload → const int
- pageSize → const int