SlottedPage class
Constructors
- SlottedPage.blank(int pageId)
- SlottedPage.fromBytes(int pageId, Uint8List src)
Properties
- checksum → int
-
no setter
- flags → int
-
no setter
- freeEnd → int
-
no setter
- freeSpace → int
-
Free space in bytes between slot array end and first tuple.
no setter
- freeStart → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lsn → int
-
no setter
- magic → int
-
no setter
- nextPage → int
-
no setter
- pageId → int
-
final
- pageType → int
-
no setter
- rawBytes → Uint8List
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotCount → int
-
no setter
- storedId → int
-
no setter
Methods
-
compact(
) → int -
insertTuple(
Uint8List tuple) → int -
isAlive(
int slotIdx) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readTuple(
int slotIdx) → Uint8List? -
scanTuples(
) → Iterable< ({Uint8List data, int slotIdx})> -
setLsn(
int lsn) → void -
setNextPage(
int pid) → void -
stampXmax(
int slotIdx, int txnId) → void -
tombstone(
int slotIdx) → void -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → PageValidation
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited