MvccTupleHeader class

Constructors

MvccTupleHeader({required int xmin, required int xmax, required int rowId, int mvccFlags = 0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDead bool
no setter
isLive bool
no setter
mvccFlags int
final
rowId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xmax int
final
xmin int
final

Methods

encode(ByteData bd, {int offset = 0}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withXmax(int txnId) MvccTupleHeader

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List data, {int offset = 0}) MvccTupleHeader

Constants

size → const int