WalBinRecord class
Constructors
Properties
- afterImage → Uint8List?
-
final
- beforeImage → Uint8List?
-
final
-
ddlPayload
→ Map<
String, dynamic> ? -
final
- flags → int
-
final
- hasAfterImage → bool
-
no setter
- hasBeforeImage → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lsn → int
-
final
- op → WalBinOp
-
final
- prevLsn → int
-
final
- rowId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableId → int
-
final
- totalSize → int
-
no setter
- txnId → int
-
final
Methods
-
encode(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Uint8List buf, int offset) → WalBinRecord?
Constants
- headerSize → const int
- magic → const int